@@ -3,7 +3,7 @@ package WiringPi::API;
 use strict;
 use warnings;
 
-our $VERSION = '2.36.7';
+our $VERSION = '2.3610_01';
 
 require XSLoader;
 XSLoader::load('WiringPi::API', $VERSION);
@@ -21,7 +21,6 @@ my @wpi_c_functions = qw(
     lcdDisplay          lcdCursor           lcdCursorBlink
     lcdSendCommand      lcdPosition         lcdDefChar
     lcdPutChar          lcdPuts             setInterrupt
-    softPwmCreate       softPwmWrite        softPwmStop
     sr595Setup          bmp180Setup         bmp180Pressure
     bmp180Temp          analogRead          analogWrite
     physPinToWpi        wiringPiVersion     ads1115Setup
@@ -38,12 +37,12 @@ my @wpi_perl_functions = qw(
     pwm_set_range   lcd_init        lcd_home            lcd_clear
     lcd_display     lcd_cursor      lcd_cursor_blink    lcd_send_cmd
     lcd_position    lcd_char_def    lcd_put_char        lcd_puts
-    set_interrupt   soft_pwm_create soft_pwm_write      soft_pwm_stop
-    shift_reg_setup bmp180_setup    bmp180_pressure     bmp180_temp
-    analog_read     analog_write    pin_mode            phys_to_wpi
+    set_interrupt   bmp180_setup    bmp180_pressure     bmp180_temp
+    shift_reg_setup analog_read     analog_write        pin_mode
     ads1115_setup   spi_setup       spi_data            i2c_setup
     i2c_interface   i2c_read        i2c_read_byte       i2c_read_word
     i2c_write       i2c_write_byte  i2c_write_word      testChar
+    phys_to_wpi
 );
 
 our @EXPORT_OK;
@@ -59,24 +58,6 @@ sub new {
     return bless {}, shift;
 }
 
-# soft PWM functions
-
-sub soft_pwm_create {
-    shift if @_ == 4;
-    my ($pin, $value, $range) = @_;
-    softPwmCreate($pin, $value, $range);
-}
-sub soft_pwm_write {
-    shift if @_ == 3;
-    my ($pin, $value) = @_;
-    softPwmWrite($pin, $value);
-}
-sub soft_pwm_stop {
-    shift if @_ == 2;
-    my $pin = shift;
-    softPwmStop($pin);
-}
-
 # interrupt functions
 
 sub set_interrupt {
@@ -115,6 +96,7 @@ sub pull_up_down {
     my ($pin, $value) = @_;
     # off, down up = 0, 1, 2
     pullUpDnControl($pin, $value);
+    select(undef, undef, undef, 0.02);
 }
 sub read_pin {
     shift if @_ == 2;
@@ -373,7 +355,7 @@ sub i2c_write_word {
         die "i2c_write_word() requires a \$data param\n";
     }
 
-    return wiringPiI2CWriteReg16($fd, $reg);
+    return wiringPiI2CWriteReg16($fd, $reg, $data);
 }
 
 # SPI functions
@@ -451,14 +433,6 @@ sub bmp180_pressure {
     # return kPa
     return bmp180Pressure($pin) / 100;
 }
-
-# threading functions
-
-sub thread_create {
-    my ($self, $sub_name) = @_;
-    my $status = initThread($sub_name);
-    print "thread failed to start\n" if $status != 0;
-}
 sub _vim{1;};
 
 1;
@@ -512,10 +486,9 @@ versions, but are still 100% compatible.
     pwm_set_range   lcd_init        lcd_home            lcd_clear
     lcd_display     lcd_cursor      lcd_cursor_blink    lcd_send_cmd
     lcd_position    lcd_char_def    lcd_put_char        lcd_puts
-    set_interrupt   soft_pwm_create soft_pwm_write      soft_pwm_stop
-    shift_reg_setup pin_mode        analog_read         analog_write
-    bmp180_setup    bmp180_pressure bmp180_temp         phys_to_wpi
-    ads1115_setup   spi_setup       spi_data
+    set_interrupt   pin_mode        analog_read         analog_write
+    shift_reg_setup bmp180_setup    bmp180_pressure     bmp180_temp
+    ads1115_setup   spi_setup       spi_data            phys_to_wpi
 
 =head1 EXPORT_TAGS
 
@@ -539,10 +512,6 @@ See L</BOARD FUNCTIONS>.
 
 See L</LCD FUNCTIONS>.
 
-=head2 SOFTWARE PWM
-
-See L</SOFT PWM FUNCTIONS>.
-
 =head2 INTERRUPT
 
 See L</INTERRUPT FUNCTIONS>.
@@ -964,15 +933,20 @@ Mandatory: The file descriptor integer returned by C<lcd_init()>.
 
     $index
 
-Mandatory: Index of the display character. Values are C<0-7>.
+Mandatory: Index of the display character. Values are C<0-7>. Once the char
+is stored at this index, it can be used at any time with the C<lcd_put_char()>
+function.
 
     $data
 
-Mandatory: Array reference. Each element is a single byte, up to a maximum of 8
-elements. These bytes represent the character from the top-line to the bottom
-line. Note that the characters are actually 5×8, so only the lower 5 bits are
-used. The index is from 0 to 7 and you can subsequently print the character
-defined using the lcdPutchar() call.
+Mandatory: Array reference of exactly 8 elements. Each element is a single
+unsigned char byte. These bytes represent the character from the top-line to
+the bottom line. 
+
+Note that the characters are actually 5 x 8, so only the lower 5 bits are of
+each element are used (ie. `0b11111` or 0b00011111`). The index is from 0 to 7
+and you can subsequently print the character defined using the lcdPutchar()
+call using the same index sent in to this function.
 
 =head2 lcd_put_char($fd, $char)
 
@@ -989,7 +963,10 @@ Mandatory: The file descriptor integer returned by C<lcd_init()>.
 
     $char
 
-Mandatory: A single ASCII character.
+Mandatory: The character byte to print to the LCD. Note that 0-7 are reserved
+for custom characters, as defined with C<lcd_char_def()>. To print one of your
+custom chars, C<$char> should be the same integer of the C<$index> you used to
+store it in that function.
 
 =head2 lcd_puts($fd, $string)
 
@@ -1007,47 +984,6 @@ Mandatory: The file descriptor integer returned by C<lcd_init()>.
 
 Mandatory: A string to display.
 
-=head1 SOFT PWM FUNCTIONS
-
-Note: The software PWM functionality is experimental, and from what I've
-tested, not very reliable, so I'd stay away from this at this time.
-
-Software Pulse Width Modulation is not the same as hardware PWM. It should not
-be used for critical things as it's frequency isn't 100% stable.
-
-This software PWM allows you to use PWM on ANY GPIO pin, not just the single
-hardware pin available.
-
-=head2 soft_pwm_create($pin, $initial_value, $range)
-
-Creates a new software PWM thread that runs outside of your main application.
-
-Parameters:
-
-    $pin
-
-Mandatory: The pin number, in the pin numbering scheme dictated by whichever
-C<setup*()> routine you used.
-
-    $initial_value
-
-Optional: A value between C<0> and C<$range>.
-
-    $range
-
-Optional: Look at this like a dial. We start at C<0> and the dial has turned
-completely when we hit the C<$range> integer. If not sent in, defaults to
-C<1023>.
-
-=head2 soft_pwm_write($pin, $value)
-
-Sets the C<HIGH> frequency on C<pin> to whatever is in C<$value>. The value must
-be lower than what was set in the C<$range> parameter to C<soft_pwm_create()>.
-
-=head2 soft_pwm_stop($pin)
-
-Turns off software PWM on the C<$pin>.
-
 =head1 INTERRUPT FUNCTIONS
 
 =head2 set_interrupt($pin, $edge, $callback)
@@ -1475,13 +1411,13 @@ Takes no parameters, returns the byte value as an unsigned int.
 
 Same as L</digitalReadByte>, but reads from the second group of eight GPIO pins.
 
-head1 AUTHOR
+=head1 AUTHOR
 
 Steve Bertrand, E<lt>steveb@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016 by Steve Bertrand
+Copyright (C) 2017 by Steve Bertrand
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.18.2 or,
